==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_amplifybackend/paginator.py <==
"""
Type annotations for amplifybackend service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_amplifybackend/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_amplifybackend.client import AmplifyBackendClient
    from types_boto3_amplifybackend.paginator import (
        ListBackendJobsPaginator,
    )

    session = Session()
    client: AmplifyBackendClient = session.client("amplifybackend")

    list_backend_jobs_paginator: ListBackendJobsPaginator = client.get_paginator("list_backend_jobs")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListBackendJobsRequestListBackendJobsPaginateTypeDef,
    ListBackendJobsResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListBackendJobsPaginator",)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListBackendJobsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amplifybackend/paginator/ListBackendJobs.html#AmplifyBackend.Paginator.ListBackendJobs)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_amplifybackend/paginators/#listbackendjobspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListBackendJobsRequestListBackendJobsPaginateTypeDef]
    ) -> _PageIterator[ListBackendJobsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amplifybackend/paginator/ListBackendJobs.html#AmplifyBackend.Paginator.ListBackendJobs.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_amplifybackend/paginators/#listbackendjobspaginator)
        """

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_amplifybackend/paginator.py <==
"""
Type annotations for amplifybackend service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_amplifybackend/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_amplifybackend.client import AmplifyBackendClient
    from types_boto3_amplifybackend.paginator import (
        ListBackendJobsPaginator,
    )

    session = Session()
    client: AmplifyBackendClient = session.client("amplifybackend")

    list_backend_jobs_paginator: ListBackendJobsPaginator = client.get_paginator("list_backend_jobs")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import ListBackendJobsRequestPaginateTypeDef, ListBackendJobsResponseTypeDef

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListBackendJobsPaginator",)


if TYPE_CHECKING:
    _ListBackendJobsPaginatorBase = Paginator[ListBackendJobsResponseTypeDef]
else:
    _ListBackendJobsPaginatorBase = Paginator  # type: ignore[assignment]


class ListBackendJobsPaginator(_ListBackendJobsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amplifybackend/paginator/ListBackendJobs.html#AmplifyBackend.Paginator.ListBackendJobs)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_amplifybackend/paginators/#listbackendjobspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListBackendJobsRequestPaginateTypeDef]
    ) -> PageIterator[ListBackendJobsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amplifybackend/paginator/ListBackendJobs.html#AmplifyBackend.Paginator.ListBackendJobs.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_amplifybackend/paginators/#listbackendjobspaginator)
        """
